#[repr(C)]pub struct DexState {Show 19 fields
pub tag: u64,
pub base_mint: Pubkey,
pub quote_mint: Pubkey,
pub base_vault: Pubkey,
pub quote_vault: Pubkey,
pub orderbook: Pubkey,
pub admin: Pubkey,
pub creation_timestamp: i64,
pub base_volume: u64,
pub quote_volume: u64,
pub accumulated_fees: u64,
pub min_base_order_size: u64,
pub royalties_bps: u64,
pub accumulated_royalties: u64,
pub base_currency_multiplier: u64,
pub quote_currency_multiplier: u64,
pub signer_nonce: u8,
pub fee_type: u8,
pub _padding: [u8; 6],
}Expand description
The primary market state object
Fields
tag: u64This u64 is used to verify and version the dex state
base_mint: PubkeyThe mint key of the base token
quote_mint: PubkeyThe mint key of the quote token
base_vault: PubkeyThe SPL token account holding the market’s base tokens
quote_vault: PubkeyThe SPL token account holding the market’s quote tokens
orderbook: PubkeyThe asset agnostic orderbook address
admin: PubkeyThe market admin which can recuperate all transaction fees
creation_timestamp: i64The market’s creation timestamp on the Solana runtime clock.
base_volume: u64The market’s total historical volume in base token
quote_volume: u64The market’s total historical volume in quote token
accumulated_fees: u64The market’s fees which are available for extraction by the market admin
min_base_order_size: u64The market’s minimum allowed order size in base token amount
royalties_bps: u64Royalties bps
accumulated_royalties: u64Accumulated royalties fees
base_currency_multiplier: u64The base currency multiplier
quote_currency_multiplier: u64The quote currency multiplier
signer_nonce: u8The signer nonce is necessary for the market to perform as a signing entity
fee_type: u8Fee type (e.g. default or stable)
_padding: [u8; 6]Padding