Struct dex_v4::state::UserAccountHeader
source · #[repr(C)]pub struct UserAccountHeader {Show 13 fields
pub tag: u64,
pub market: Pubkey,
pub owner: Pubkey,
pub base_token_free: u64,
pub base_token_locked: u64,
pub quote_token_free: u64,
pub quote_token_locked: u64,
pub accumulated_rebates: u64,
pub accumulated_maker_quote_volume: u64,
pub accumulated_maker_base_volume: u64,
pub accumulated_taker_quote_volume: u64,
pub accumulated_taker_base_volume: u64,
pub number_of_orders: u32,
/* private fields */
}Expand description
This header describes a user account’s state
Fields
tag: u64This byte is used to verify and version the dex state
market: PubkeyThe user account’s assocatied DEX market
owner: PubkeyThe user account owner’s wallet
base_token_free: u64The amount of base token available for settlement
base_token_locked: u64The amount of base token currently locked in the orderbook
quote_token_free: u64The amount of quote token available for settlement
quote_token_locked: u64The amount of quote token currently locked in the orderbook
accumulated_rebates: u64The all time quantity of rebates accumulated by this user account.
The actual rebates will always be transfer to the user account’s main balance. This field is just a metric.
accumulated_maker_quote_volume: u64The accumulated maker quote volume of the user. This field is just a metric.
accumulated_maker_base_volume: u64The accumulated maker quote volume of the user. This field is just a metric.
accumulated_taker_quote_volume: u64The accumulated taker quote volume of the user. This field is just a metric.
accumulated_taker_base_volume: u64The accumulated taker quote volume of the user. This field is just a metric.
number_of_orders: u32The user account’s number of active orders.